==> EXOSIMS-3.2.2.tar.gz: EXOSIMS-3.2.2/README.md <==
![Alt text](EXOSIMS_cropped.png)
Exoplanet Open-Source Imaging Mission Simulator

<a href="http://ascl.net/1706.010"><img src="https://img.shields.io/badge/ascl-1706.010-blue.svg?colorB=262255" alt="ascl:1706.010" /></a>
![Build Status](https://github.com/dsavransky/EXOSIMS/actions/workflows/ci.yml/badge.svg)
[![Documentation Status](https://readthedocs.org/projects/exosims/badge/?version=latest)](https://exosims.readthedocs.io/en/latest/?badge=latest)
[![Coverage Status](https://coveralls.io/repos/github/dsavransky/EXOSIMS/badge.svg?branch=master)](https://coveralls.io/github/dsavransky/EXOSIMS?branch=master)
[![PyPI version](https://badge.fury.io/py/EXOSIMS.svg)](https://badge.fury.io/py/EXOSIMS)
[![astropy](http://img.shields.io/badge/powered%20by-AstroPy-orange.svg?style=flat)](http://www.astropy.org/)
[![Contributor Covenant](https://img.shields.io/badge/Contributor%20Covenant-2.1-4baaaa.svg)](code_of_conduct.md)

Quick Install
--------------------------
Clone the repository, navigate to the top level directory (containing setup.py) and execute:
```
pip install -e .
```
Full installation and configuration instructions available here: https://exosims.readthedocs.io/en/latest/install.html

Documentation and Quick Start Guide
-----------------------------------------------------------
- https://exosims.readthedocs.io
- https://exosims.readthedocs.io/en/latest/quickstart.html

Additional EXOSIMS tutorials are available here: https://github.com/dsavransky/YieldModelingWorkshopTutorial 
This repository is associated with the Yield Modeling Tools Workshops.  For additional information, see here: https://exoplanets.nasa.gov/exep/events/456/exoplanet-yield-modeling-tools-workshop/

Contributing
-------------------------------------
All contributions are very welcome.  Before starting on your first contribution to EXOSIMS, please read the [Contributing Guide](https://github.com/dsavransky/EXOSIMS/blob/master/CONTRIBUTING.md)


Credits and Acknowledgements
------------------------------
Created by Dmitry Savransky

Written by Christian Delacroix, Daniel Garrett, Dean Keithly, Gabriel Soto, Corey Spohn, Walker Dula, Sonny Rappaport, Michael Turmon, Rhonda Morgan, Grace Genszler, and Dmitry Savransky, with contributions by Patrick Lowrance, Ewan Douglas, Jackson Kulik, Jeremy Turner, Jayson Figueroa, Owen Sorber and Neil Zimmerman.

EXOSIMS makes use of Astropy, a community-developed core Python package for Astronomy (Astropy Collaboration, 2013).

EXOSIMS optionally makes use of Forecaster (http://ascl.net/1701.007).

EXOSIMS optionally makes use of NASA's Navigation and Ancillary Information Facility's SPICE system components (https://naif.jpl.nasa.gov/naif/).

EXOSIMS optionally uses values from: Mamjek, E. "A Modern Mean Dwarf Stellar Color and Effective Temperature Sequence", http://www.pas.rochester.edu/~emamajek/EEM_dwarf_UBVIJHK_colors_Teff.txt, Version 2017.09.06

EXOSIMS development is supported by NASA Grant Nos. NNX14AD99G (GSFC), NNX15AJ67G (WPS) and NNG16PJ24C (SIT).

For further information, please see EXOSIMS's ASCL page and the following papers:
- http://adsabs.harvard.edu/abs/2016JATIS...2a1006S
- http://adsabs.harvard.edu/abs/2016SPIE.9911E..19D

==> EXOSIMS-3.3.0.tar.gz: EXOSIMS-3.3.0/README.md <==
![Alt text](EXOSIMS_cropped.png)
Exoplanet Open-Source Imaging Mission Simulator

<a href="http://ascl.net/1706.010"><img src="https://img.shields.io/badge/ascl-1706.010-blue.svg?colorB=262255" alt="ascl:1706.010" /></a>
![Build Status](https://github.com/dsavransky/EXOSIMS/actions/workflows/ci.yml/badge.svg)
[![Documentation Status](https://readthedocs.org/projects/exosims/badge/?version=latest)](https://exosims.readthedocs.io/en/latest/?badge=latest)
[![Coverage Status](https://coveralls.io/repos/github/dsavransky/EXOSIMS/badge.svg?branch=master)](https://coveralls.io/github/dsavransky/EXOSIMS?branch=master)
[![PyPI version](https://badge.fury.io/py/EXOSIMS.svg)](https://badge.fury.io/py/EXOSIMS)
[![astropy](http://img.shields.io/badge/powered%20by-AstroPy-orange.svg?style=flat)](http://www.astropy.org/)
[![Contributor Covenant](https://img.shields.io/badge/Contributor%20Covenant-2.1-4baaaa.svg)](code_of_conduct.md)

Quick Install
--------------------------
Clone the repository, navigate to the top level directory (containing setup.py) and execute:
```
pip install -e .
```
Full installation and configuration instructions available here: https://exosims.readthedocs.io/en/latest/install.html

Documentation and Quick Start Guide
-----------------------------------------------------------
- https://exosims.readthedocs.io
- https://exosims.readthedocs.io/en/latest/quickstart.html

Additional EXOSIMS tutorials are available here: https://github.com/dsavransky/YieldModelingWorkshopTutorial 
This repository is associated with the Yield Modeling Tools Workshops.  For additional information, see here: https://exoplanets.nasa.gov/exep/events/456/exoplanet-yield-modeling-tools-workshop/

Contributing
-------------------------------------
All contributions are very welcome.  Before starting on your first contribution to EXOSIMS, please read the [Contributing Guide](https://github.com/dsavransky/EXOSIMS/blob/master/CONTRIBUTING.md)


Credits and Acknowledgements
------------------------------
Created by Dmitry Savransky

Written by Christian Delacroix, Daniel Garrett, Dean Keithly, Gabriel Soto, Corey Spohn, Walker Dula, Sonny Rappaport, Michael Turmon, Rhonda Morgan, Grace Genszler, and Dmitry Savransky, with contributions by Patrick Lowrance, Ewan Douglas, Jackson Kulik, Jeremy Turner, Jayson Figueroa, Owen Sorber, Maxwell Zweig, and Neil Zimmerman.

EXOSIMS makes use of Astropy, a community-developed core Python package for Astronomy (Astropy Collaboration, 2013).

EXOSIMS optionally makes use of Forecaster (http://ascl.net/1701.007).

EXOSIMS optionally makes use of NASA's Navigation and Ancillary Information Facility's SPICE system components (https://naif.jpl.nasa.gov/naif/).

EXOSIMS optionally uses values from: Mamjek, E. "A Modern Mean Dwarf Stellar Color and Effective Temperature Sequence", http://www.pas.rochester.edu/~emamajek/EEM_dwarf_UBVIJHK_colors_Teff.txt, Version 2017.09.06

EXOSIMS development is supported by NASA Grant Nos. NNX14AD99G (GSFC), NNX15AJ67G (WPS) and NNG16PJ24C (SIT).

For further information, please see EXOSIMS's ASCL page and the following papers:
- http://adsabs.harvard.edu/abs/2016JATIS...2a1006S
- http://adsabs.harvard.edu/abs/2016SPIE.9911E..19D
